Learn R Programming

lga (version 1.1-0)

lga-package: The lga Package

Description

The lga package is an implementation of the algorithms described in Van Aelst et al (2006) and Garcia-Escudero et al (2008). It has three main functions (with accompanying print and plot methods). {The core linear grouping analysis} rlga{The robust version of linear grouping analysis} gap{Performs a gap analysis to find the number of clusters}

Arguments

References

Van Aelst, S. and Wang, X. and Zamar, R. and Zhu, R. (2006) Linear Grouping Using Orthogonal Regression, Computational Statistics & Data Analysis 50, 1287--1312.

Garcia-Escudero, L. and Gordaliz, A. and San Martin, R. and Van Aelst, S. and Zamar, R.H. (2008) Robust linear clustering. Unpublished Manuscript.