Learn R Programming

lga (version 1.0-0)

lga-package: The lga Package

Description

The lga package is an implementation of the algorithms described in Van Aelst et al (2006). It has two main functions (both with accompanying print and plot methods). {The core linear grouping analysis} gap{Performs a gap analysis to find the number of clusters}

Arguments

References

Van Aelst, S. and Wang, X. and Zamar, R. and Zhu, R. (2006) Linear Grouping Using Orthogonal Regression, Computational Statistics & Data Analysis 50, 1287--1312.